<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About MystiQ</source>
        <translation>MystiQ Hakkında</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Bilgi</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>Çevirenler</translation>
    </message>
    <message>
        <source>Portable</source>
        <translation>Taşınabilir</translation>
    </message>
    <message>
        <source>Compiled with Qt %1</source>
        <translation>Qt ile derlendi %1</translation>
    </message>
    <message>
        <source>Compiled with libnotify %1</source>
        <translation>Libnotify ile derlendi %1</translation>
    </message>
    <message>
        <source>MystiQ Homepage: %1</source>
        <translation>MystiQ Ana Sayfası: %1</translation>
    </message>
    <message>
        <source>Some audio-processing functionalities are provided by SoX.</source>
        <translation>Bazı ses işleme işlevleri SoX tarafından sağlanır.</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <extracomment>Spanish Language (Spain)</extracomment>
        <translation>İspanyolca (İspanya)</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Lisans</translation>
    </message>
    <message>
        <source>MystiQ is a GUI frontend for FFmpeg.</source>
        <translation>MystiQ, FFmpeg için bir Arayüz ön ucudur.</translation>
    </message>
    <message>
        <source>Developers:&lt;br&gt; %1</source>
        <translation>Geliştiriciler:&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <extracomment>Swedish Language (Sweden)</extracomment>
        <translation>İsveççe (İsveç)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <extracomment>Japanese Language (Japan)</extracomment>
        <translation>Japonca (Japonya)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <extracomment>German Language (Germany)</extracomment>
        <translation>Almanca (Almanya)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <extracomment>Italian Language (Italy)</extracomment>
        <translation>İtalyanca (İtalya)</translation>
    </message>
    <message>
        <source>Application Name:&lt;br&gt; %1</source>
        <translation>Uygulama Adı:&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 3.</source>
        <translation>Bu program özgür bir yazılımdır; GNU Genel Kamu Lisansı sürüm 3 şartları altında yeniden dağıtabilir veya değiştirebilirsiniz.</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <extracomment>Turkish Language (Turkey)</extracomment>
        <translation>Türkçe (Türkiye)</translation>
    </message>
    <message>
        <source>Many people have contributed translations. You can also help translate the MystiQ Video Converter into your own language. Visit </source>
        <translation>Birçok insan çeviriye katkıda bulundu. MystiQ Video Converter&apos;ı kendi dilinize çevirmenize de yardımcı olabilirsiniz. Ziyaret edin </translation>
    </message>
    <message>
        <source> and join a translation team.</source>
        <translation> ve bir çeviri ekibine katılın.</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation>Değişiklikler</translation>
    </message>
    <message>
        <source>Hungarian (Hungary)</source>
        <extracomment>Hungarian Language (Hungary)</extracomment>
        <translation>Macarca (Macaristan)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <extracomment>Russian Language (Russia)</extracomment>
        <translation>Rusça (Rusya)</translation>
    </message>
    <message>
        <source>Collaborators:&lt;br&gt; %1</source>
        <translation>İşbirlikçiler:&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Some features of MystiQ Video Converter have been inspired by</source>
        <translation>MystiQ Video Converter&apos;ın bazı özelliklerinden ilham alınmıştır</translation>
    </message>
    <message>
        <source>Galician (Galicia)</source>
        <extracomment>Galician Language (Galicia)</extracomment>
        <translation>Galiçyaca (Galiçya)</translation>
    </message>
    <message>
        <source>Icons Theme:&lt;br&gt; %1</source>
        <translation>Simgeler Tema: &lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Indonesian (Indonesia)</source>
        <extracomment>Indonesian Language (Indonesia)</extracomment>
        <translation>Endonezce (Endonezya)</translation>
    </message>
</context>
<context>
    <name>AboutFFmpegDialog</name>
    <message>
        <source>About FFmpeg</source>
        <translation>FFmpeg Hakkında</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Available Codecs</source>
        <translation>Kullanılabilir Çözücüler</translation>
    </message>
    <message>
        <source>FFmpeg is a complete, cross-platform solution to record, convert and stream audio and video. It includes libavcodec - the leading audio/video codec library.</source>
        <extracomment>ffmpeg description</extracomment>
        <translation>FFmpeg, ses ve video kaydetmek, dönüştürmek ve akışını gerçekleştirmek için eksiksiz, platformlar arası bir çözümdür. Başarılır ses/video çözücü kütüphanesi olan libavcodec&apos;i içerir.</translation>
    </message>
    <message>
        <source>FFmpeg is free software licensed under the LGPL or GPL.</source>
        <translation>FFmpeg, LGPL veya GPL altında lisanslı ücretsiz bir yazılımdır.</translation>
    </message>
    <message>
        <source>Please visit %1 for more information.</source>
        <translation>Daha fazla bilgi için %1 adresini ziyaret edin.</translation>
    </message>
</context>
<context>
    <name>AddTaskWizard</name>
    <message>
        <source>Add Tasks</source>
        <translation>Görev Ekle</translation>
    </message>
    <message>
        <source>Files to be converted</source>
        <translation>Dönüştürülecek dosyalar</translation>
    </message>
    <message>
        <source>Add files.</source>
        <translation>Dosya ekle.</translation>
    </message>
    <message>
        <source>Remove selected files.</source>
        <translation>Seçili dosyaları kaldır.</translation>
    </message>
    <message>
        <source>Output Settings</source>
        <translation>Çıktı Ayarları</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <source>Auto adjust output bitrate to reduce output file size.</source>
        <translation>Çıktı dosya boyutunu azaltmak için bit hızını otomatik olarak ayarla.</translation>
    </message>
    <message>
        <source>Auto Adjust Audio Bitrate</source>
        <translation>Ses Bit Hızını Otomatik Ayarla</translation>
    </message>
    <message>
        <source>Preset</source>
        <translation>Önayar</translation>
    </message>
    <message>
        <source>Convert to</source>
        <translation>Dönüştür</translation>
    </message>
    <message>
        <source>Output Path</source>
        <translation>Çıktı Yolu</translation>
    </message>
    <message>
        <source>Select &amp;folder</source>
        <translation>&amp;Klasör seç</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Gözat</translation>
    </message>
    <message>
        <source>Create &amp;new folder in source folder</source>
        <extracomment>Create a new folder (e.g. mystiq_output) in the folder containing the input files. Put the output files in the newly created folder.</extracomment>
        <translation>Kaynak klasörde &amp;yeni klasör oluştur</translation>
    </message>
    <message>
        <source>Folder Name</source>
        <translation>Klasör Adı</translation>
    </message>
    <message>
        <source>Output to &amp;source folder</source>
        <extracomment>put the output files in the same folder as the input files</extracomment>
        <translation>Çıktı klasörü &amp;kaynak klasörde</translation>
    </message>
    <message>
        <source>Please select at least one file.</source>
        <translation>Lütfen en az bir dosya seç.</translation>
    </message>
    <message>
        <source>Select Files</source>
        <extracomment>This text is the title of an openfile dialog.</extracomment>
        <translation>Dosya Seç</translation>
    </message>
    <message>
        <source>Multimedia</source>
        <translation>Çoklu ortam</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tüm dosyalar</translation>
    </message>
    <message>
        <source>Select Directory</source>
        <extracomment>This text is the title of an open directory dialog.</extracomment>
        <translation>Dizin Seç</translation>
    </message>
    <message>
        <source>Searching for files...</source>
        <translation>Dosyalar aranıyor...</translation>
    </message>
    <message>
        <source>Some files could not be found.</source>
        <translation>Bazı dosyalar bulunamadı.</translation>
    </message>
    <message>
        <source>Folder does not exist. Create a new folder?</source>
        <translation>Klasör mevcut değil. Yeni bir klasör oluşturulsun mu?</translation>
    </message>
    <message>
        <source>Failed to create folder. Please select another output folder.</source>
        <translation>Klasör oluşturulamadı. Lütfen başka bir çıktı klasörü seç.</translation>
    </message>
    <message>
        <source>Add Files</source>
        <translation>Dosya Ekle</translation>
    </message>
    <message>
        <source>Remove Selected</source>
        <translation>Seçilenleri Kaldır</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>Listeyi Temizle</translation>
    </message>
</context>
<context>
    <name>ConversionParameterDialog</name>
    <message>
        <source>Conversion Parameters</source>
        <translation>Dönüşüm Parametreleri</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Disable Audio</source>
        <translation>Ses Devre Dışı</translation>
    </message>
    <message>
        <source>Audio Options</source>
        <translation>Ses Seçenekleri</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Örnekleme Hızı</translation>
    </message>
    <message>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation>Bit Hızı</translation>
    </message>
    <message>
        <source>(auto)</source>
        <translation>(otomatik)</translation>
    </message>
    <message>
        <source>kb/s</source>
        <translation>kb/s</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Kanallar</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Seviye</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Disable Video</source>
        <translation>Video Devre Dışı</translation>
    </message>
    <message>
        <source>Video Options</source>
        <translation>Video Seçenekleri</translation>
    </message>
    <message>
        <source>Same Quantizer as Source</source>
        <translation>Kaynakla Aynı Nitelikte</translation>
    </message>
    <message>
        <source>Deinterlace</source>
        <translation>Ayrıştır</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Genişlik</translation>
    </message>
    <message>
        <source> px</source>
        <translation> pk</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Yükseklik</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Kırp</translation>
    </message>
    <message>
        <source>Time</source>
        <extracomment>time-related options (speed, length)</extracomment>
        <translation>Zaman</translation>
    </message>
    <message>
        <source>Cutting</source>
        <extracomment>video time cutting: options for begin time and end time</extracomment>
        <translation>Kesim</translation>
    </message>
    <message>
        <source>Cut</source>
        <comment>Cut video; select a range to convert</comment>
        <translation>Kes</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Önizle</translation>
    </message>
    <message>
        <source>Scaling</source>
        <extracomment>time scaling, changing the speed of the output file</extracomment>
        <translation>Ölçek</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hız</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Gelişmiş</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Additional FFmpeg Options</source>
        <translation>Ek FFmpeg Seçenekleri</translation>
    </message>
    <message>
        <source>Copy Audio (Do not re-encode)</source>
        <translation>Sesi Kopyala (Yeniden kodlanmaz)</translation>
    </message>
    <message>
        <source>Insert Subtitle if Available</source>
        <translation>Varsa Altyazı Ekle</translation>
    </message>
    <message>
        <source>Copy Video (Do not re-encode)</source>
        <translation>Videoyu Kopyala (Yeniden kodlanmaz)</translation>
    </message>
    <message>
        <source>qrc:/qml/main.qml</source>
        <translation>qrc:/qml/main.qml</translation>
    </message>
    <message>
        <source>Video Extra Options</source>
        <translation>Video Ekstra Seçenekleri</translation>
    </message>
    <message>
        <source>Video to Black and White</source>
        <translation>Videoyu Siyah Beyaz</translation>
    </message>
    <message>
        <source>Vertical Flip</source>
        <translation>Dikey Çevir</translation>
    </message>
    <message>
        <source>Horizontal Flip</source>
        <translation>Yatay Çevir</translation>
    </message>
    <message>
        <source>Rotate 90 degrees clockwise</source>
        <translation>Saat yönünde 90 derece döndür</translation>
    </message>
    <message>
        <source>Rotate 90 degrees counterclockwise</source>
        <translation>Saat yönünün tersine 90 derece döndür</translation>
    </message>
    <message>
        <source>Rotate 180 degrees</source>
        <translation>180 derece döndür</translation>
    </message>
    <message>
        <source>3D Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Blue Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Dubois</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green Magenta Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Half Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow Blue Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green Magenta Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Green Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConvertList</name>
    <message>
        <source>Cancel</source>
        <extracomment>Cancel the operation of adding new tasks</extracomment>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Adding files (%1/%2)</source>
        <extracomment>This text is the progress indicator of adding multiple tasks. %1 is the number of files that are already added. %2 is the total number of files.</extracomment>
        <translation>Eklenen dosyalar (%1/%2)</translation>
    </message>
    <message>
        <source>Some files are not recognized by the converter.</source>
        <translation>Bazı dosyalar dönüştürücü tarafından tanınmıyor.</translation>
    </message>
    <message>
        <source>New File Name</source>
        <translation>Yeni Dosya Adı</translation>
    </message>
    <message>
        <source>Please input the new name for the output file.</source>
        <translation>Lütfen çıktı dosyası için yeni bir isim gir.</translation>
    </message>
    <message>
        <source>Output Directory</source>
        <translation>Çıktı Dizini</translation>
    </message>
    <message>
        <source>Error Message from FFmpeg:

</source>
        <translation>FFmpeg&apos;den Hata İletisi:

</translation>
    </message>
    <message>
        <source>Drag and drop files here to add tasks.</source>
        <translation>Görev eklemek için dosyaları buraya sürükle bırak.</translation>
    </message>
    <message>
        <source>Hide &quot;%1&quot;</source>
        <extracomment>Hide a column in the list. For example, the text maybe &apos;Hide &quot;Duration&quot;&apos;. The two &quot; are quotation marks in English, you may replace it with local quotation marks.</extracomment>
        <translation>Gizle &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Restore All Columns</source>
        <translation>Tüm Sütunları Onar</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Kaynak</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Hedef</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Süre</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Dosya Boyutu</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <extracomment>Audio</extracomment>
        <translation>Örnekleme Hızı</translation>
    </message>
    <message>
        <source>Audio Bitrate</source>
        <translation>Ses Bit Hızı</translation>
    </message>
    <message>
        <source>Channels</source>
        <extracomment>Audio</extracomment>
        <translation>Kanallar</translation>
    </message>
    <message>
        <source>Audio Codec</source>
        <translation>Ses Çözücü</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Boyutlar</translation>
    </message>
    <message>
        <source>Video Bitrate</source>
        <translation>Video Bit Hızı</translation>
    </message>
    <message>
        <source>Framerate</source>
        <extracomment>Video</extracomment>
        <translation>Kare Hızı</translation>
    </message>
    <message>
        <source>Video Codec</source>
        <translation>Video Çözücü</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>İlerleyiş</translation>
    </message>
    <message>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
    <message>
        <source>%1 kb/s</source>
        <translation>%1 kb/s</translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <source>Removing tasks...</source>
        <extracomment>Remove files from the tasklist</extracomment>
        <translation>Görevler kaldırılıyor...</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>GiB</source>
        <translation>GB</translation>
    </message>
    <message>
        <source>TiB</source>
        <translation>TB</translation>
    </message>
    <message>
        <source>B</source>
        <extracomment>Bytes</extracomment>
        <translation>B</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>Dosya Zaten Var</translation>
    </message>
    <message>
        <source>%1 already exists on disk or in the task list. Still use this name as the output filename?</source>
        <translation>%1 zaten diskte veya görev listesinde var. Bu dosya çıktı dosyası adı olarak kullanılsın mı?</translation>
    </message>
    <message>
        <source>Remove Task</source>
        <translation>Görevi Kaldır</translation>
    </message>
    <message>
        <source>Cannot remove a task while it is in progress.</source>
        <translation>Bir görev devam ederken kaldırılamaz.</translation>
    </message>
    <message>
        <source>Finished</source>
        <extracomment>The text to be displayed on the progress bar when a conversion finishes</extracomment>
        <translation>Tamamlandı</translation>
    </message>
    <message>
        <source>Failed</source>
        <extracomment>The text to be displayed on the progress bar when a conversion fails</extracomment>
        <translation>Başarısız</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <extracomment>%1 is the error message</extracomment>
        <translation>Hata: %1</translation>
    </message>
</context>
<context>
    <name>ExtraTranslations</name>
    <message>
        <source>Convert between media file formats</source>
        <translation>Ortam dosya biçimleri arası dönüşüm</translation>
    </message>
    <message>
        <source>Media Converter</source>
        <translation>Ortam Dönüştürücü</translation>
    </message>
</context>
<context>
    <name>HelpMystiQDialog</name>
    <message>
        <source>User Manual</source>
        <translation>Kullanım Kılavuzu</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Fira Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;MystiQ User&apos;s Manual&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/mystiq_96x96.png&quot; style=&quot;float: left;&quot; /&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is a cross platform application. This application has as its sole objective the conversion of audio and video files to multiple formats. As a distinctive feature, MystiQ is an open source project, which means that the source code will always be available and everyone who wishes to contribute to the development is welcome.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is free: you can redistribute it and / or modify it under the terms GNU (General Public License) published by the Free Software Foundation. MystiQ Video Converter is freely distributed with the sole purpose of being a useful application to your needs, but WITHOUT NO WARRANTY, even if its use is COMMERCIAL or MERELY A PARTICULAR PURPOSE See the GPL v3 license for more details. This application includes an English copy of the Software distribution license.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The essential idea of ​​the development team is to provide a friendly and simple user interface. The simple is the essence of MystiQ, which means that it is not our objective to add features that complicate the operation of the application.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Currently MystiQ is mainly developed in C ++ taking advantage of the Qt5 graphic libraries. In the FFmpeg backend he is in charge of converting between formats, so we can say that MystiQ is simply a graphical interface for FFmpeg.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ currently allows you to convert to most existing video formats, as well as make it possible to extract audio and convert between audio formats. It also includes a small tool to trim videos based on the duration of these.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter currently supports the following audio and video formats:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Audio: mp3 m4a 3g2 ogg wav wma  ac3 ra ape flac opus&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Video: avi vfw divx mpg mpeg m1v m2v mpv dv 3gp mov mp4 m4v mqv dat vcd ogg ogm ogv asf wmv bin iso vob mkv nsv ram flv rm swf ts rmvb dvr-ms m2t m2ts rec mts webm dv&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot1.png&quot; /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Toolbar&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;In the upper part of the main window of the application we will find the toolbar with the following buttons:&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot2.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;ul style=&quot;margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;&quot;&gt;&lt;li style=&quot;&quot; style=&quot; margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Add Files:&lt;/span&gt; &lt;span style=&quot; font-size:12pt;&quot;&gt;Opens a dialog to select the video files you want to convert. Once selected, they are placed in the List of Conversion Tasks&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Start: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Start conversion process from the list of loaded items&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Stop: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Stops the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry All:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the conversion process of all items in the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Selected:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove a selected item from the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Completed:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the list that have completed the conversion process&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Clear List:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the conversion list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Open Output Folder: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;From the system file manager open the folder that contains the converted files&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot; font-size:12pt;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Power Options:&lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;  &lt;/span&gt;Choose whether to shut down, suspend or hibernate the computer when completing the conversion process of all items in the list&lt;/li&gt;&lt;/ul&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Audio Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot3.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Audio:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding sound.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Copy audio (do not recode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the audio from the source file. The resulting file will have the same sound parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Sample Rate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; In audio production, a sample rate (or &amp;quot;sampling rate&amp;quot;) defines how many times per second a sound is sampled. Technically speaking, it is the frequency of samples used in a digital recording.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Bitrate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; It&apos;s the bit rate or data that is processed per unit of time. The average bitrate for an MP3 file is 128 kbits per second or kbps.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Channels: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the passage way a signal or data is transported. In case of audio files, it&apos;s the passage or communication channel in which a sound signal is transported from the player source to the speaker. An audio file can contain one, two or even more Channels.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Volume: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Allows you to configure the maximum volume of the destination file taking as a match the volume level of the source file.&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Video Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot4.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Insert Subtitle if Available: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;By checking this option, the application will verify if a subtitle file of the same name is found in the same location of the source file, if found, it will embed it in the resulting file. It is currently compatible with subtitles in SRT, SSA, ASS and SUB format.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Video:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding video.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Copy Video (Do not re-encode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the video from the source file. The resulting file will have the same video parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Video to Black and White: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It allows to obtain a video file is grayscale.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Flip and Rotate options: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The resulting file will be rotated or flipped in the direction chosen.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Deinterlace: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the process of converting interlaced video, such as common analog television signals or 1080i format HDTV signals, into a non-interlaced form. An interlaced video frame consists of two sub-fields taken in sequence, each sequentially scanned at odd, and then even, lines of the image sensor.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Same Quantizer as source: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s involved in image processing, is a lossy compression technique achieved by compressing a range of values to a single quantum value. Checking this option the resulting file will have the same deinterlacing as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Fira Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;MystiQ Kullanıcı Kılavuzu&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/mystiq_96x96.png&quot; style=&quot;float: left;&quot; /&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter bir çapraz platform uygulamasıdır. Bu uygulama tek amacı olarak ses ve video dosyalarının birden fazla biçime dönüştürülmesine sahiptir. Ayırt edici bir özellik olarak, MystiQ açık kaynaklı bir projedir, yani kaynak kod her zaman kullanılabilir olacak ve gelişime katkıda bulunmak isteyen herkesin hoş karşılanması anlamına gelir.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter ücretsizdir: Ücretsiz Yazılım Vakfı tarafından yayınlanan GNU (Genel Kamu Lisansı) terimleri altında yeniden dağıtabilir ve / veya değiştirebilirsiniz. MystiQ Video Converter, yalnızca gereksinimleriniz için yararlı bir uygulama olmak amacıyla serbestçe dağıtılır, ancak kullanımı TİCARİ veya MERKEZİ BİR ÖZEL AMAÇLI olsa bile, GARANTİ YOKTUR Daha fazla bilgi için GPL v3 lisansına bakın. Bu uygulama, Yazılım dağıtım lisansının İngilizce bir kopyasını içerir.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Geliştirme ekibinin temel fikri, kolay ve basit bir kullanıcı arayüzü sağlamaktır. Basit olan MystiQ&apos;nun özüdür, bu da uygulamanın çalışmasını zorlaştıran özellikler eklemenin amacımız olmadığı anlamına gelir.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Şu anda MystiQ esas olarak Qt5 grafik kütüphanelerinden faydalanarak C ++ &apos;da geliştirilmiştir. FFmpeg arka ucunda, formatlar arasında dönüştürme yapmaktan sorumludur, bu yüzden MystiQ&apos;nun sadece FFmpeg için grafik bir arayüz olduğunu söyleyebiliriz.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ şu anda mevcut video formatlarının çoğuna dönüştürme yapabilmenin yanı sıra ses çıkarmayı ve ses formatları arasında dönüştürme yapmayı mümkün kılıyor. Ayrıca, videoların sürelerine göre kırpmak için küçük bir araç da içerir.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter şu anda aşağıdaki ses ve video formatlarını desteklemektedir:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Ses: mp3 m4a 3g2 ogg wav wma  ac3 ra ape flac opus&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Video: avi vfw divx mpg mpeg m1v m2v mpv dv 3gp mov mp4 m4v mqv dat vcd ogg ogm ogv asf wmv bin iso vob mkv nsv ram flv rm swf ts rmvb dvr-ms m2t m2ts rec mts webm dv&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot1.png&quot; /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Araç Çubuğu&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Uygulamanın ana penceresinin üst kısmında araç çubuğunu aşağıdaki düğmelerle bulacağız:&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot2.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;ul style=&quot;margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;&quot;&gt;&lt;li style=&quot;&quot; style=&quot; margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Dosya Ekle:&lt;/span&gt; &lt;span style=&quot; font-size:12pt;&quot;&gt;Dönüştürmek istediğiniz video dosyalarını seçmek için bir iletişim kutusu açar. Seçildikten sonra, Dönüşüm Görevleri Listesine yerleştirilirler&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Başlat: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Bir ögeyi dönüştürme işlemini başlatır&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Durdur: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Bir ögeyi dönüştürme işlemini durdurur&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Yeniden dene:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Bir ögeyi dönüştürme işlemini yeniden dener &lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Tümünü yeniden dene:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Dönüştürme listesindeki tüm ögeleri yeniden dener &lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Seçileni Kaldır:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Seçili ögeyi listeden kaldırır &lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Tamamlananları Kaldır:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Tamamlanan ögelerin tümünü listeden kaldırır &lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Listeyi Temizle:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Dönüşüm listesindeki ögeleri temizle&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Çıkış Klasörünü Aç: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Sistem dosya yöneticisinden dönüştürülen dosyaları içeren klasörü açar&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot; font-size:12pt;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Güç Seçenekleri:&lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;  &lt;/span&gt;Listedeki tüm ögelerin dönüştürme işlemini tamamlarken bilgisayarı kapatmayı, askıya almayı veya hazırda bekletmeyi seçmeyi seçer&lt;/li&gt;&lt;/ul&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Ses Seçenekleri&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot3.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Sesi İptal Et:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Ses olmadan bir dosya elde etmenizi sağlar.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Sesi kopyala (yeniden kodlamadan):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Kaynak dosyadaki sesi işlemeden dönüştürmenizi sağlar. Ortaya çıkan dosya, kaynak dosyayla aynı ses parametrelerine sahip olacaktır.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Sample Rate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; In audio production, a sample rate (or &amp;quot;sampling rate&amp;quot;) defines how many times per second a sound is sampled. Technically speaking, it is the frequency of samples used in a digital recording.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Bitrate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; It&apos;s the bit rate or data that is processed per unit of time. The average bitrate for an MP3 file is 128 kbits per second or kbps.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Kanallar: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the passage way a signal or data is transported. In case of audio files, it&apos;s the passage or communication channel in which a sound signal is transported from the player source to the speaker. An audio file can contain one, two or even more Channels.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Ses: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Allows you to configure the maximum volume of the destination file taking as a match the volume level of the source file.&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Video Seçenekleri&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot4.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Insert Subtitle if Available: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;By checking this option, the application will verify if a subtitle file of the same name is found in the same location of the source file, if found, it will embed it in the resulting file. It is currently compatible with subtitles in SRT, SSA, ASS and SUB format.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Video:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding video.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Copy Video (Do not re-encode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the video from the source file. The resulting file will have the same video parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Video to Black and White: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It allows to obtain a video file is grayscale.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Flip and Rotate options: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The resulting file will be rotated or flipped in the direction chosen.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Deinterlace: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the process of converting interlaced video, such as common analog television signals or 1080i format HDTV signals, into a non-interlaced form. An interlaced video frame consists of two sub-fields taken in sequence, each sequentially scanned at odd, and then even, lines of the image sensor.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Same Quantizer as source: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s involved in image processing, is a lossy compression technique achieved by compressing a range of values to a single quantum value. Checking this option the resulting file will have the same deinterlacing as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>InteractiveCuttingDialog</name>
    <message>
        <source>Cutting</source>
        <comment>Cutting as in &quot;cutting video&quot;</comment>
        <translation>Kesim</translation>
    </message>
    <message>
        <source>Mark as Begin</source>
        <translation>Başlangıcı ​​İşaretle</translation>
    </message>
    <message>
        <source>Seek to Begin</source>
        <translation>Başlangıç Noktasına Git</translation>
    </message>
    <message>
        <source>Play Selection</source>
        <translation>Seçimi Oynat</translation>
    </message>
    <message>
        <source>Mark as End</source>
        <translation>Bitişi İşaretle</translation>
    </message>
    <message>
        <source>Seek to End</source>
        <translation>Bitiş Noktasına Git</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Start conversion process.</source>
        <translation>Dönüşüm işlemini başlat.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Dosya</translation>
    </message>
    <message>
        <source>&amp;Convert</source>
        <translation>&amp;Dönüştür</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Düzenle</translation>
    </message>
    <message>
        <source>&amp;Add Files</source>
        <translation>&amp;Dosya Ekle</translation>
    </message>
    <message>
        <source>Add files for conversion.</source>
        <translation>Dönüştürmek için dosya ekle.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Çıkış</translation>
    </message>
    <message>
        <source>Exit the program.</source>
        <translation>Programdan çık.</translation>
    </message>
    <message>
        <source>S&amp;top</source>
        <translation>&amp;Durdur</translation>
    </message>
    <message>
        <source>Stop conversion process.</source>
        <translation>Dönüşüm işlemini durdur.</translation>
    </message>
    <message>
        <source>Set &amp;Parameters</source>
        <translation>&amp;Parametreleri Ayarla</translation>
    </message>
    <message>
        <source>Set Parameters</source>
        <extracomment>Edit output file parameters.</extracomment>
        <translation>Parametreleri Ayarla</translation>
    </message>
    <message>
        <source>Edit conversion parameters of selected files.</source>
        <translation>Seçili dosyaların dönüşüm parametrelerini düzenle.</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt Hakkında</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Qt Hakkında</translation>
    </message>
    <message>
        <source>&amp;Open Output Folder</source>
        <translation>&amp;Çıktı Klasörünü Aç</translation>
    </message>
    <message>
        <source>Open output folder of the selected file.</source>
        <translation>Seçilen dosyanın çıktı klasörünü açar.</translation>
    </message>
    <message>
        <source>About &amp;FFmpeg</source>
        <translation>&amp;FFmpeg Hakkında</translation>
    </message>
    <message>
        <source>About FFmpeg</source>
        <translation>FFmpeg Hakkında</translation>
    </message>
    <message>
        <source>&amp;Remove Selected</source>
        <extracomment>remove selected (tasks, items)</extracomment>
        <translation>&amp;Seçilenleri Kaldır</translation>
    </message>
    <message>
        <source>Remove all selected items in the list.</source>
        <translation>Listedeki tüm seçili ögeleri kaldır.</translation>
    </message>
    <message>
        <source>R&amp;emove Completed</source>
        <extracomment>remove completed (task, items)</extracomment>
        <translation>&amp;Tamamlananları Kaldır</translation>
    </message>
    <message>
        <source>Remove Completed Items</source>
        <translation>Tamamlanan Ögeleri Kaldır</translation>
    </message>
    <message>
        <source>Remove all completed items in the list.</source>
        <translation>Listedeki tüm tamamlanmış ögeleri kaldır.</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>Listeyi Temizle</translation>
    </message>
    <message>
        <source>Remove all items in the list.</source>
        <translation>Listedeki tüm ögeleri kaldır.</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>&amp;Tekrarla</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Tekrarla</translation>
    </message>
    <message>
        <source>Retry selected tasks.</source>
        <translation>Seçili görevi tekrarla.</translation>
    </message>
    <message>
        <source>Retry &amp;All</source>
        <translation>&amp;Tümünü Tekrarla</translation>
    </message>
    <message>
        <source>Retry all tasks.</source>
        <translation>Tüm görevleri tekrarla.</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Seçenekler</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>About This Program</source>
        <translation>Bu Program Hakkında</translation>
    </message>
    <message>
        <source>Change Output &amp;Filename</source>
        <translation>&amp;Çıktı Dosya Adını Değiştir</translation>
    </message>
    <message>
        <source>Change the output filename of the selected item.</source>
        <translation>Seçilen ögenin çıktı dosya adını değiştir.</translation>
    </message>
    <message>
        <source>Change Output &amp;Directory</source>
        <translation>&amp;Çıktı Dizinini Değiştir</translation>
    </message>
    <message>
        <source>Change the output directory of the selected items.</source>
        <translation>Seçili ögelerin çıktı dizinini değiştir.</translation>
    </message>
    <message>
        <source>Show Error &amp;Message</source>
        <translation>&amp;Hata İletilerini Göster</translation>
    </message>
    <message>
        <source>Check For &amp;Updates</source>
        <translation>&amp;Güncellemeleri Kontrol Et</translation>
    </message>
    <message>
        <source>Cut</source>
        <extracomment>Cut video file (select a time range to conert)</extracomment>
        <translation>Kes</translation>
    </message>
    <message>
        <source>All tasks have finished.</source>
        <translation>Tüm görevler bitti.</translation>
    </message>
    <message>
        <source>Nothing to convert.</source>
        <translation>Dönüştürecek bir şey yok.</translation>
    </message>
    <message>
        <source>Conversion is still in progress. Abort?</source>
        <translation>Dönüşüm hala devam ediyor. İptal?</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer (completely poweroff)</extracomment>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Shutdown when all tasks are done.</source>
        <translation>Tüm görevler tamamlandığında kapat.</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Askıya Al</translation>
    </message>
    <message>
        <source>Suspend when all tasks are done.</source>
        <translation>Tüm görevler tamamlandığında askıya al.</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hazırda Beklet</translation>
    </message>
    <message>
        <source>Hibernate when all tasks are done.</source>
        <translation>Tüm görevler tamamlandığında hazırda beklet.</translation>
    </message>
    <message>
        <source>This program is going to check for updates online. Do you allow this program to use the Internet to check for updates?</source>
        <translation>Bu program çevrimiçi güncellemeleri kontrol edecektir.  İnternet&apos;i kullanmasına izin veriyor musunuz?</translation>
    </message>
    <message>
        <source>Failed to load preset file. The application will quit now.</source>
        <translation>Önceden ayarlanmış dosya yüklenemedi. Uygulama şimdi sonlandırılacak.</translation>
    </message>
    <message>
        <source>Elapsed Time: %1 h %2 m %3 s</source>
        <translation>Geçen Zaman: %1 s %2 d %3 s</translation>
    </message>
    <message>
        <source>MystiQ Media Converter</source>
        <translation>MystiQ Ortam Dönüştürücü</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Clear &amp;List</source>
        <translation>&amp;Listeyi Temizle</translation>
    </message>
    <message>
        <source>About MystiQ</source>
        <translation>MystiQ Hakkında</translation>
    </message>
    <message>
        <source>Poweroff</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>User Manual</source>
        <translation>Kullanım Kılavuzu</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;Report Error</source>
        <translation>&amp;Hata Bildir</translation>
    </message>
    <message>
        <source>Report Error</source>
        <translation>Hata Bildir</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Bağış</translation>
    </message>
    <message>
        <source>Conversion failed.</source>
        <translation>Dönüşüm başarısız.</translation>
    </message>
    <message>
        <source>Support MystiQ</source>
        <translation>MystiQ Destek</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>MystiQ needs you</source>
        <translation>MystiQ&apos;nin sana ihtiyacı var</translation>
    </message>
    <message>
        <source>MystiQ is free software. However the development requires a lot of time and a lot of work. In order to keep developing MystiQ with new features we need your help. Please consider to support the MystiQ project by sending a donation. &lt;b&gt;Even the smallest amount will help a lot.&lt;/b&gt;</source>
        <translation>MystiQ ücretsiz bir yazılımdır. Bununla birlikte, geliştirme çok zaman ve çok çalışma gerektirir. MystiQ&apos;yu yeni özelliklerle geliştirmeye devam etmek için yardımınıza ihtiyacımız var. Lütfen bağış göndererek MystiQ projesini desteklemeyi düşünün. &lt;b&gt;En küçük miktar bile çok yardımcı olacaktır.&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Reporting bugs from MystiQ </source>
        <translation>MystiQ&apos;dan gelen hataları bildir </translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Your comment:</source>
        <translation>Yorumun:</translation>
    </message>
    <message>
        <source>Report:</source>
        <translation>Bildir:</translation>
    </message>
    <message>
        <source>MystiQ is Converting %1/%2</source>
        <extracomment>Converting the %1-th file in %2 files. %2 is the number of files.</extracomment>
        <translation>MystiQ Dönüştürüyor %1/%2</translation>
    </message>
    <message>
        <source>MystiQ Video Converter</source>
        <translation>MystiQ Video Dönüştürücü</translation>
    </message>
    <message>
        <source>Conversion finished successfully.</source>
        <translation>Dönüşüm başarıyla tamamlandı.</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Çeviri</translation>
    </message>
    <message>
        <source>Translate Application</source>
        <translation>Uygulama Çevirisi</translation>
    </message>
    <message>
        <source>Report Bugs</source>
        <translation>Hataları Bildir</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-posta</translation>
    </message>
    <message>
        <source>We need your feedback</source>
        <translation>Görüşlerinize ihtiyacımız var</translation>
    </message>
    <message>
        <source>Github</source>
        <translation>Github</translation>
    </message>
    <message>
        <source>MystiQ Video Converter development team needs users who use the application to help detect errors. If you find an error and report it to our team, it will help speed up the correction process. Therefore, you can be part of our development team even if you are not a developer. To report an error, you can send us an email with the detailed description of it or you can enter Github and describe the issue (in this case you must have a GitHub Account).</source>
        <translation>MystiQ Video Converter geliştirme ekibi hataları tespit etmek için uygulamayı kullanan kullanıcılara ihtiyaç duyar. Bir hata bulursanız ve ekibimize bildirirseniz, düzeltme işleminin hızlandırılmasına yardımcı olur. Bu nedenle, geliştirici olmasanız bile geliştirme ekibimizin bir parçası olabilirsiniz. Bir hatayı bildirmek için bize ayrıntılı açıklamasını içeren bir e-posta gönderebilir veya Github&apos;a girip sorunu açıklayabilirsiniz (bu durumda bir GitHub Hesabınız olmalıdır).</translation>
    </message>
    <message>
        <source>Gitter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaConverter</name>
    <message>
        <source> FFmpeg or FFprobe %1 have not been found in the system. Please consider installing them before running MystiQ</source>
        <extracomment>%1 is a computer program</extracomment>
        <translation> Sistemde %1 FFmpeg veya FFprobe bulunamadı. Lütfen MystiQ&apos;yu çalıştırmadan önce bunları kurmayı düşünün</translation>
    </message>
</context>
<context>
    <name>MediaPlayerWidget</name>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Başlangıçta güncellemeleri kontrol et</translation>
    </message>
    <message>
        <source>Automatically start conversion after adding files to the list.</source>
        <translation>Listeye dosya eklediğinde otomatik olarak dönüşümü başlat.</translation>
    </message>
    <message>
        <source>Start conversion automatically</source>
        <translation>Dönüşümü otomatik olarak başlat</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Number of threads to use in conversion</source>
        <translation>Dönüşümde kullanılacak iş parçacığı sayısı</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Hide output formats that are not available in the current ffmpeg installation. It is recommended to turn this option on unless you are sure that MystiQ has failed to detect available formats. (requires restarting MystiQ to take effect)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Mevcut ffmpeg kurulumunda bulunmayan çıktı biçimlerini gizleyin. MystiQ&apos;nun kullanılabilir biçimlerini algılayamadığından emin değilseniz bu seçeneği açmanız önerilir. (etkin olması için MystiQ&apos;nun yeniden başlatılması gerekir)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Hide unavailable formats (requires restarting)</source>
        <translation>Kullanılamayan biçimleri gizle (yeniden başlatma gerekir)</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Araçlar</translation>
    </message>
    <message>
        <source>You have to restart MystiQ for the changes to take effect.</source>
        <translation>Değişikliklerin geçerli olması için MystiQ&apos;yu yeniden başlatmanız gerekir.</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Komut</translation>
    </message>
</context>
<context>
    <name>PoweroffDialog</name>
    <message>
        <source>MystiQ</source>
        <translation>MystiQ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Shutdown immediately</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Hemen kapat</translation>
    </message>
    <message>
        <source>Suspend immediately</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Hemen askıya al</translation>
    </message>
    <message>
        <source>Hibernate immediately</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hemen hazırda beklet</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Askıya Al</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hazırda Beklet</translation>
    </message>
    <message>
        <source>Operation Failed: %1</source>
        <translation>İşlem Başarısız: %1</translation>
    </message>
    <message>
        <source>Shutting down in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; saniye içinde kapanacak</translation>
    </message>
    <message>
        <source>Suspending in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; saniye içinde askıya alınacak</translation>
    </message>
    <message>
        <source>Hibernating in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; saniye içinde hazırda bekletilecek</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <source>Play Selected Range</source>
        <translation>Seçilen Aralığı Oynat</translation>
    </message>
    <message>
        <source>Begin</source>
        <extracomment>noun, the beginning of the video</extracomment>
        <translation>Başlangıç</translation>
    </message>
    <message>
        <source>End</source>
        <extracomment>noun, the end of the video</extracomment>
        <translation>Bitiş</translation>
    </message>
    <message>
        <source>Play %1~%2</source>
        <extracomment>play the video from time %1 to time %2. %1 and %2 are time in hh:mm:ss format.</extracomment>
        <translation>Oynat %1~%2</translation>
    </message>
    <message>
        <source>Video Preview</source>
        <translation>Video Ön İzlemesi</translation>
    </message>
</context>
<context>
    <name>TimeRangeEdit</name>
    <message>
        <source>From Begin</source>
        <translation>Başlangıç</translation>
    </message>
    <message>
        <source>To End</source>
        <translation>Bitiş</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Show &amp;Release Notes</source>
        <translation>&amp;Sürüm Notlarını Göster</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Başlangıçta güncellemeleri kontrol et</translation>
    </message>
    <message>
        <source>Downloading update information...</source>
        <translation>Güncelleme bilgileri indiriliyor...</translation>
    </message>
    <message>
        <source>Cannot connect to server.</source>
        <translation>Sunucuya bağlanamıyor.</translation>
    </message>
    <message>
        <source>Failed to parse the received data.</source>
        <translation>Alınan veriler ayrıştırılamadı.</translation>
    </message>
    <message>
        <source>You are already using the latest version of MystiQ.</source>
        <translation>MystiQ&apos;nun en son sürümünü zaten kullanıyorsunuz.</translation>
    </message>
    <message>
        <source>An unknown error has occurred.</source>
        <translation>Bilinmeyen bir hata oluştu.</translation>
    </message>
    <message>
        <source>A new version of MystiQ has been released!</source>
        <translation>MystiQ&apos;nun yeni bir sürümü çıktı!</translation>
    </message>
    <message>
        <source>Version &lt;b&gt;%1&lt;/b&gt; is available at %2.</source>
        <extracomment>%1 is version number, %2 is the project homepage</extracomment>
        <translation>Sürüm &lt;b&gt;%1&lt;/b&gt; adresinde mevcut %2.</translation>
    </message>
    <message>
        <source>You can download this version using the link:</source>
        <translation>Bu sürümü aşağıdaki bağlantıdan indirebilirsiniz:</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Güncellemeyi Kontrol Et</translation>
    </message>
    <message>
        <source>The current version you are using is newer than the release channel version.&lt;br&gt;Therefore, you are using the development channel.</source>
        <translation>Kullandığınız mevcut sürüm, yayın kanalı sürümünden daha yenidir.&lt;br&gt;Bu nedenle, geliştirme kanalını kullanıyorsunuz.</translation>
    </message>
</context>
</TS>
